@@ -4,7 +4,7 @@ clean_path <- function(path) {
     ""
   } else if (grepl("^(http|ftp|https)://", path)) {
     tmp <- tempfile()
-    download.file(path, tmp, quiet = TRUE, mode = "wb")
+    utils::download.file(path, tmp, quiet = TRUE, mode = "wb")
     tmp
   } else {
     normalizePath(path, mustWork = TRUE)
