@@ -9,6 +9,6 @@
 #ifndef Wizard_readstat_por_parse_h
 #define Wizard_readstat_por_parse_h
 
-int readstat_por_parse_double(const char *data, size_t len, double *result, readstat_error_handler error_cb);
+int readstat_por_parse_double(const char *data, size_t len, double *result, readstat_error_handler error_cb, void *user_ctx);
 
 #endif
